==> python-ovmclient-1.0.0.tar.gz: python-ovmclient-1.0.0/ovmclient/constants.py <==
# Copyright (c) 2017 Cloudbase Solutions Srl
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

JOB_RUN_STATE_NONE = "NONE"
JOB_RUN_STATE_CREATED = "CREATED"
JOB_RUN_STATE_RUNNING = "RUNNING"
JOB_RUN_STATE_SUCCESS = "SUCCESS"
JOB_RUN_STATE_FAILURE = "FAILURE"
JOB_RUN_STATE_CHILD_QUEUED = "CHILD_QUEUED"
JOB_RUN_STATE_CHILD_RUNNING = "CHILD_RUNNING"

VM_DOMAIN_TYPE_XEN_PVM = "XEN_PVM"
VM_DOMAIN_TYPE_XEN_HVM = "XEN_HVM"
VM_DOMAIN_TYPE_XEN_HVM_PV_DRIVERS = "XEN_HVM_PV_DRIVERS"
VM_DOMAIN_TYPE_LDOMS_PVM = "LDOMS_PVM"
VM_DOMAIN_TYPE_UNKNOWN = "UNKNOWN"

DISK_WRITE_MODE_READ_ONLY = "READ_ONLY"
DISK_WRITE_MODE_READ_WRITE = "READ_WRITE"

DISK_TYPE_VIRTUAL_DISK = "VIRTUAL_DISK"
DISK_TYPE_VIRTUAL_CDROM = "VIRTUAL_CDROM"

IP_ADDRESS_TYPE_IPV4 = "IPV4"
IP_ADDRESS_TYPE_IPV6 = "IPV6"
IP_ADDRESS_TYPE_UNKNOWN = "UNKNOWN"

IP_ADDRESS_CONFIG_TYPE_STATIC = "STATIC"
IP_ADDRESS_CONFIG_TYPE_DYNAMIC = "DYNAMIC"
IP_ADDRESS_CONFIG_TYPE_STATELESS_AUTOCONFIG = "STATELESS_AUTOCONFIG"
IP_ADDRESS_CONFIG_TYPE_UNKNOWN = "UNKNOWN"

MANAGER_RUN_STATE_STARTING = "STARTING"
MANAGER_RUN_STATE_RUNNING = "RUNNING"
MANAGER_RUN_STATE_STOPPING = "STOPPING"
MANAGER_RUN_STATE_STOPPED = "STOPPED"

==> python-ovmclient-1.0.2.tar.gz: python-ovmclient-1.0.2/ovmclient/constants.py <==
# Copyright (c) 2017 Cloudbase Solutions Srl
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

JOB_RUN_STATE_NONE = "NONE"
JOB_RUN_STATE_CREATED = "CREATED"
JOB_RUN_STATE_RUNNING = "RUNNING"
JOB_RUN_STATE_SUCCESS = "SUCCESS"
JOB_RUN_STATE_FAILURE = "FAILURE"
JOB_RUN_STATE_CHILD_QUEUED = "CHILD_QUEUED"
JOB_RUN_STATE_CHILD_RUNNING = "CHILD_RUNNING"

VM_DOMAIN_TYPE_XEN_PVM = "XEN_PVM"
VM_DOMAIN_TYPE_XEN_HVM = "XEN_HVM"
VM_DOMAIN_TYPE_XEN_HVM_PV_DRIVERS = "XEN_HVM_PV_DRIVERS"
VM_DOMAIN_TYPE_LDOMS_PVM = "LDOMS_PVM"
VM_DOMAIN_TYPE_UNKNOWN = "UNKNOWN"

DISK_WRITE_MODE_READ_ONLY = "READ_ONLY"
DISK_WRITE_MODE_READ_WRITE = "READ_WRITE"

DISK_TYPE_VIRTUAL_DISK = "VIRTUAL_DISK"
DISK_TYPE_VIRTUAL_CDROM = "VIRTUAL_CDROM"

IP_ADDRESS_TYPE_IPV4 = "IPV4"
IP_ADDRESS_TYPE_IPV6 = "IPV6"
IP_ADDRESS_TYPE_UNKNOWN = "UNKNOWN"

IP_ADDRESS_CONFIG_TYPE_STATIC = "STATIC"
IP_ADDRESS_CONFIG_TYPE_DYNAMIC = "DYNAMIC"
IP_ADDRESS_CONFIG_TYPE_STATELESS_AUTOCONFIG = "STATELESS_AUTOCONFIG"
IP_ADDRESS_CONFIG_TYPE_UNKNOWN = "UNKNOWN"

MANAGER_RUN_STATE_STARTING = "STARTING"
MANAGER_RUN_STATE_RUNNING = "RUNNING"
MANAGER_RUN_STATE_STOPPING = "STOPPING"
MANAGER_RUN_STATE_STOPPED = "STOPPED"

CLONE_TYPE_THIN_CLONE = "THIN_CLONE"
CLONE_TYPE_SPARSE_COPY = "SPARSE_COPY"
CLONE_TYPE_NON_SPARSE_COPY = "NON_SPARSE_COPY"
